==> v0.7.10.zip: antares/src/renderer/i18n/ja-JP.ts <==
export const jaJP = {
   word: {
      edit: '編集',
      save: '保存',
      close: '閉じる',
      delete: '削除',
      confirm: '確認',
      cancel: 'キャンセル',
      send: '送信',
      connectionName: '接続名',
      client: 'クライアント',
      hostName: 'ホスト名',
      port: 'ポート',
      user: 'ユーザー名',
      password: 'パスワード',
      credentials: '認証情報',
      connect: '接続',
      connected: '接続中',
      disconnect: '接続解除',
      disconnected: '接続解除',
      refresh: 'リフレッシュ',
      settings: '設定',
      general: '一般',
      themes: 'テーマ',
      update: '更新情報',
      // about: 'お問い合わせ',
      language: '言語',
      version: 'バージョン',
      donate: '寄付する',
      run: '実行',
      schema: 'スキーマ',
      results: '結果',
      size: 'サイズ',
      seconds: '秒数',
      type: 'タイプ',
      mimeType: 'マイムタイプ',
      download: 'ダウンロード',
      add: '追加',
      data: 'データ',
      properties: 'プロパティ',
      insert: '挿入',
      connecting: '接続',
      name: '名称',
      collation: '照合',
      clear: 'クリア',
      options: 'オプション',
      autoRefresh: 'オートリフレシュ',
      indexes: 'インデックス',
      foreignKeys: '外部キー',
      length: '長さ',
      unsigned: '符号なし',
      default: 'デフォルト',
      comment: 'コメント',
      key: 'キー | キー',
      order: '順序',
      expression: '表現',
      autoIncrement: 'オートインクリメント',
      engine: 'エンジン',
      field: 'フィールド | フィールド',
      approximately: '約',
      total: '合計',
      table: 'テーブル',
      discard: '破棄',
      stay: 'ステイ',
      author: '作者',
      light: 'ライト',
      dark: 'ダーク',
      autoCompletion: 'オートコンプリート',
      application: 'アプリケーション',
      editor: 'エディター',
      view: 'ビュー',
      definer: 'デファイナー',
      algorithm: 'アルゴリズム',
      trigger: 'トリガー | トリガー',
      storedRoutine: 'ストアド・ルーチン | ストアド・ルーチン',
      scheduler: 'スケジューラー | スケジューラー',
      event: 'イベント',
      parameters: 'パラメータ',
      function: '関数 | 関数',
      // deterministic: '決定論的',
      context: 'コンテキスト',
      export: 'エクスポート',
      returns: '戻り値',
      timing: 'タイミング',
      state: '状態',
      execution: '実行',
      starts: '開始',
      ends: '終了',
      ssl: 'SSL',
      privateKey: '秘密鍵',
      certificate: '証明書',
      caCertificate: 'CA 証明書',
      ciphers: '暗号',
      upload: 'アップロード',
      browse: '閲覧',
      faker: 'フェイカー',
      content: 'コンテンツ',
      cut: 'カット',
      copy: 'コピー',
      paste: '貼り付け',
      tools: 'ツール',
      variables: '変数',
      processes: 'プロセス',
      database: 'データベース',
      scratchpad: 'スクラッチパッド',
      array: '配列',
      changelog: '変更履歴',
      format: 'フォーマット',
      sshTunnel: 'SSH トンネル',
      structure: '構造',
      // small: '小規模',
      // medium: '中型',
      // large: 'ラージ',
      row: 'ロウ | ロウ',
      cell: 'セル | セル',
      triggerFunction: 'トリガー関数 | トリガー関数',
      all: 'すべて',
      duplicate: 'デュプリケート',
      routine: 'ルーチン',
      // new: '新機能',
      history: '履歴',
      select: '選択'
   },
   message: {
      appWelcome: 'Antares SQL Client へようこそ!',
      appFirstStep: '最初のステップは、新しいデータベース接続を作成することです。',
      addConnection: '接続の追加',
      createConnection: '接続の作成',
      createNewConnection: '新しい接続の作成',
      askCredentials: '認証情報の入力',
      testConnection: '接続のテスト',
      editConnection: '接続の編集',
      deleteConnection: '接続の削除',
      deleteCorfirm: 'のキャンセルを確認しますか？',
      connectionSuccessfullyMade: '接続に成功しました。',
      madeWithJS: '💛 と JavaScript で作られています。',
      checkForUpdates: '更新情報の確認',
      noUpdatesAvailable: 'アップデートがありません',
      checkingForUpdate: 'アップデートを確認中',
      checkFailure: 'チェックに失敗しました、後で試してください',
      updateAvailable: 'アップデートが利用可能です',
      downloadingUpdate: 'アップデートのダウンロード',
      updateDownloaded: 'アップデートのダウンロード',
      restartToInstall: 'Antares を再起動してインストールしてください',
      unableEditFieldWithoutPrimary: '主キーのないフィールドを結果セットで編集できない',
      editCell: 'セルの編集',
      deleteRows: '行の削除 | {count} 行の削除',
      confirmToDeleteRows: '1つの行を削除することを確認しますか？ | {count} 行を削除することを確認しますか？',
      notificationsTimeout: '通知のタイムアウト',
      uploadFile: 'ファイルのアップロード',
      addNewRow: '新しい行の追加',
      numberOfInserts: 'インサート数',
      openNewTab: '新しいタブを開く',
      affectedRows: '影響を受ける行',
      createNewDatabase: '新規データベースの作成',
      databaseName: 'データベース名',
      serverDefault: 'サーバーのデフォルト',
      deleteDatabase: 'データベースの削除',
      editDatabase: 'データベースの編集',
      clearChanges: '変更の消去',
      addNewField: '新しいフィールドの追加',
      manageIndexes: 'インデックスの管理',
      manageForeignKeys: '外部キーの管理',
      allowNull: 'NULL を許可する',
      zeroFill: 'ゼロフィル',
      customValue: 'カスタム値',
      onUpdate: '更新時',
      deleteField: 'フィールドの削除',
      createNewIndex: '新しいインデックスの作成',
      addToIndex: 'インデックスへの追加',
      createNewTable: '新しいテーブルの作成',
      emptyTable: '空のテーブル',
      deleteTable: 'テーブルの削除',
      emptyCorfirm: '空にすることを確認しますか？',
      unsavedChanges: '保存されていない変更',
      discardUnsavedChanges: '保存されていない変更があります。このタブを閉じると、これらの変更は破棄されます。',
      thereAreNoIndexes: 'インデックスがありません',
      thereAreNoForeign: '外部キーがありません。',
      createNewForeign: '新しい外部キーの作成',
      referenceTable: '参照テーブル',
      referenceField: '参照フィールド',
      foreignFields: '外部フィールド',
      invalidDefault: '無効なデフォルト',
      onDelete: '削除時',
      applicationTheme: 'アプリケーションテーマ',
      editorTheme: 'エディターテーマ',
      wrapLongLines: '長い行の折り返し',
      selectStatement: '選択文',
      triggerStatement: 'トリガー文',
      sqlSecurity: 'SQL セキュリティ',
      updateOption: '更新オプション',
      deleteView: 'ビューの削除',
      createNewView: '新規ビューの作成',
      deleteTrigger: 'トリガーの削除',
      createNewTrigger: '新しいトリガの作成',
      currentUser: '現在のユーザー',
      routineBody: 'ルーチン本体',
      dataAccess: 'データアクセス',
      thereAreNoParameters: 'パラメータはありません',
      createNewParameter: '新しいパラメータの作成',
      createNewRoutine: 'ストアド・ルーチンの新規作成',
      deleteRoutine: 'ストアド・ルーチンの削除',
      functionBody: '関数本体',
      createNewFunction: '新しい関数の作成',
      deleteFunction: '関数の削除',
      schedulerBody: 'スケジューラ本体',
      createNewScheduler: 'スケジューラの新規作成',
      deleteScheduler: 'スケジューラの削除',
      preserveOnCompletion: '完了時に保存する',
      enableSsl: 'SSL 対応',
      manualValue: 'マニュアル値',
      tableFiller: 'テーブルフィラー',
      fakeDataLanguage: 'フェイクデータの言語',
      searchForElements: '要素の検索',
      selectAll: 'すべてを選択する',
      queryDuration: '問い合わせ期間',
      includeBetaUpdates: 'ベータ版アップデートを含む',
      setNull: 'NULL の設定',
      processesList: 'プロセス一覧',
      processInfo: 'プロセス情報',
      manageUsers: 'ユーザーの管理',
      createNewSchema: '新しいスキーマの作成',
      schemaName: 'スキーマ名',
      editSchema: 'スキーマの編集',
      deleteSchema: 'スキーマの削除',
      markdownSupported: 'マークダウン対応',
      // plantATree: '木を植える',
      dataTabPageSize: 'DATA タブのページサイズ',
      enableSsh: 'SSH を有効にする',
      pageNumber: 'ページ番号',
      duplicateTable: 'テーブルを複製する',
      noOpenTabs: '開いているタブがありません。左のバーでナビゲートするか',
      noSchema: 'スキーマなし',
      restorePreviourSession: '前のセッションに戻す',
      runQuery: 'クエリの実行',
      thereAreNoTableFields: 'テーブルのフィールドがありません',
      newTable: '新しいテーブル',
      newView: '新しいビュー',
      newTrigger: '新しいトリガー',
      newRoutine: '新しいルーチン',
      newFunction: '新しい関数',
      newScheduler: '新規スケジューラ',
      newTriggerFunction: '新しいトリガー機能',
      thereIsNoQueriesYet: 'まだ問い合わせはありません',
      searchForQueries: 'クエリの検索',
      killProcess: 'プロセスの停止'
   },
   faker: {
      address: '住所',
      commerce: 'コマース',
      company: '会社名',
      database: 'データベース',
      date: '日付',
      finance: 'ファイナンス',
      // git: 'ギット',
      hacker: 'ハッカー',
      internet: 'インターネット',
      // lorem: 'ローレム',
      name: '名前',
      music: '音楽',
      phone: '電話',
      random: 'ランダム',
      system: 'システム',
      time: '時間',
      vehicle: '車',
      zipCode: '郵便番号',
      zipCodeByState: '都道府県別郵便番号',
      city: '都市名',
      cityPrefix: '市のプレフィックス',
      citySuffix: '市の接尾辞',
      streetName: '通りの名前',
      streetAddress: 'ストリートアドレス',
      streetSuffix: '通りの接尾辞',
      streetPrefix: 'ストリートプレフィックス',
      secondaryAddress: '副住所',
      county: '郡',
      country: '国名',
      countryCode: '国コード',
      state: '州',
      stateAbbr: '州の略語',
      latitude: '緯度',
      longitude: '経度',
      direction: '方向',
      cardinalDirection: '枢機卿の方向',
      ordinalDirection: '序列方向',
      nearbyGPSCoordinate: '近くのGPS座標',
      timeZone: 'タイムゾーン',
      color: '色',
      department: '部門',
      productName: '商品名',
      price: '価格',
      productAdjective: '製品の形容詞',
      productMaterial: '製品の素材',
      product: '製品',
      productDescription: '製品の説明',
      suffixes: 'サフィックス',
      companyName: '会社名',
      companySuffix: '会社のサフィックス',
      catchPhrase: 'キャッチフレーズ',
      // bs: 'BS',
      catchPhraseAdjective: 'キャッチフレーズ形容詞',
      catchPhraseDescriptor: 'キャッチフレーズの説明文',
      catchPhraseNoun: 'キャッチフレーズの名詞',
      bsAdjective: 'BS 形容詞',
      bsBuzz: 'BS の話題',
      bsNoun: 'BS の名詞',
      column: 'コラム',
      type: 'タイプ',
      collation: '照合',
      engine: 'エンジン',
      past: '過去',
      future: '未来',
      between: '間',
      recent: '最近',
      soon: 'すぐ',
      month: '月',
      weekday: '曜日',
      account: 'アカウント',
      accountName: '口座名',
      routingNumber: 'ルーティング番号',
      mask: 'マスク',
      amount: '金額',
      transactionType: '取引の種類',
      currencyCode: '通貨コード',
      currencyName: '通貨名',
      currencySymbol: '通貨記号',
      bitcoinAddress: 'Bitcoin アドレス',
      litecoinAddress: 'ライトコインのアドレス',
      creditCardNumber: 'クレジットカード番号',
      creditCardCVV: 'クレジットカードの CVV',
      ethereumAddress: 'イーサリアムのアドレス',
      iban: 'アイバン',
      bic: 'ビック',
      transactionDescription: '取引内容',
      branch: 'ブランチ',
      commitEntry: 'コミットエントリ',
      commitMessage: 'コミットメッセージ',
      commitSha: 'コミット SHA',
      shortSha: 'ショート SHA',
      abbreviation: '省略形',
      adjective: '形容詞',
      noun: '名詞',
      verb: '動詞',
      ingverb: '動詞',
      phrase: 'フレーズ',
      avatar: 'アバター',
      email: 'メール',
      exampleEmail: 'メールの例',
      userName: 'ユーザー名',
      protocol: 'プロトコル',
      url: 'URL',
      domainName: 'ドメイン名',
      domainSuffix: 'ドメインのサフィックス',
      domainWord: 'ドメイン名',
      ip: 'Ip',
      ipv6: 'Ipv6',
      userAgent: 'ユーザーエージェント',
      // mac: 'Mac',
      password: 'パスワード',
      word: 'ワード',
      words: '単語',
      sentence: '文章',
      slug: 'スラッグ',
      sentences: 'センテンス',
      paragraph: 'パラグラフ',
      paragraphs: 'パラグラフ',
      text: 'テキスト',
      lines: '行',
      genre: 'ジャンル',
      firstName: 'ファーストネーム',
      lastName: '苗字',
      middleName: 'ミドルネーム',
      findName: 'フルネーム',
      jobTitle: '役職名',
      gender: '性別',
      prefix: 'プレフィックス',
      suffix: 'サフィックス',
      title: '役職名',
      jobDescriptor: '職務記述書',
      jobArea: '職務領域',
      jobType: '仕事の種類',
      phoneNumber: '電話番号',
      phoneNumberFormat: '電話番号のフォーマット',
      phoneFormats: '電話番号のフォーマット',
      // number: '番号',
      // float: 'フロート',
      arrayElement: '配列要素',
      arrayElements: '配列要素',
      objectElement: 'オブジェクトの要素',
      // uuid: 'Uuid',
      // boolean: 'ブール',
      image: '画像',
      locale: 'ロケール',
      alpha: '英字',
      alphaNumeric: '英数字',
      hexaDecimal: '16進法',
      fileName: 'ファイル名',
      commonFileName: '一般的なファイル名',
      mimeType: 'Mimeタイプ',
      commonFileType: '共通のファイルタイプ',
      commonFileExt: '共通のファイル拡張子',
      fileType: 'ファイルタイプ',
      fileExt: 'ファイル拡張子',
      directoryPath: 'ディレクトリパス',
      filePath: 'ファイルパス',
      // semver: 'セムバー',
      manufacturer: 'メーカー名',
      model: 'モデル',
      fuel: '燃料'
      // vin: 'Vin'
   }
};

==> v0.7.21.zip: antares/src/renderer/i18n/ja-JP.ts <==
export const jaJP = {
   general: {
      edit: '編集',
      save: '保存',
      close: '閉じる',
      delete: '削除',
      confirm: '確認',
      cancel: 'キャンセル',
      send: '送信',
      refresh: 'リフレッシュ',
      autoRefresh: 'オートリフレシュ',
      version: 'バージョン',
      donate: '寄付する',
      run: '実行',
      results: '結果',
      size: 'サイズ',
      mimeType: 'マイムタイプ',
      download: 'ダウンロード',
      add: '追加',
      data: 'データ',
      properties: 'プロパティ',
      insert: '挿入',
      name: '名称',
      clear: 'クリア',
      seconds: '秒数',
      options: 'オプション',
      discard: '破棄',
      stay: 'ステイ',
      author: '作者',
      upload: 'アップロード',
      browse: '閲覧',
      content: 'コンテンツ',
      cut: 'カット',
      copy: 'コピー',
      paste: '貼り付け',
      tools: 'ツール',
      format: 'フォーマット',
      all: 'すべて',
      duplicate: 'デュプリケート',
      history: '履歴',
      select: '選択',
      deleteConfirm: 'のキャンセルを確認しますか？',
      uploadFile: 'ファイルのアップロード',
      manualValue: 'マニュアル値',
      selectAll: 'すべてを選択する',
      pageNumber: 'ページ番号'
   },
   connection: {
      connectionName: '接続名',
      client: 'クライアント',
      hostName: 'ホスト名',
      port: 'ポート',
      user: 'ユーザー名',
      password: 'パスワード',
      credentials: '認証情報',
      connect: '接続',
      connected: '接続中',
      disconnect: '接続解除',
      disconnected: '接続解除',
      ssl: 'SSL',
      privateKey: '秘密鍵',
      certificate: '証明書',
      caCertificate: 'CA 証明書',
      ciphers: '暗号',
      sshTunnel: 'SSH トンネル',
      addConnection: '接続の追加',
      createConnection: '接続の作成',
      createNewConnection: '新しい接続の作成',
      askCredentials: '認証情報の入力',
      testConnection: '接続のテスト',
      editConnection: '接続の編集',
      deleteConnection: '接続の削除',
      connectionSuccessfullyMade: '接続に成功しました。',
      enableSsl: 'SSL 対応',
      enableSsh: 'SSH を有効にする'
   },
   database: {
      schema: 'スキーマ',
      type: 'タイプ',
      foreignKeys: '外部キー',
      length: '長さ',
      unsigned: '符号なし',
      default: 'デフォルト',
      comment: 'コメント',
      collation: '照合',
      key: 'キー | キー',
      order: '順序',
      expression: '表現',
      autoIncrement: 'オートインクリメント',
      engine: 'エンジン',
      field: 'フィールド | フィールド',
      approximately: '約',
      total: '合計',
      table: 'テーブル',
      view: 'ビュー',
      indexes: 'インデックス',
      definer: 'デファイナー',
      algorithm: 'アルゴリズム',
      trigger: 'トリガー | トリガー',
      storedRoutine: 'ストアド・ルーチン | ストアド・ルーチン',
      scheduler: 'スケジューラー | スケジューラー',
      event: 'イベント',
      parameters: 'パラメータ',
      function: '関数 | 関数',
      context: 'コンテキスト',
      export: 'エクスポート',
      returns: '戻り値',
      timing: 'タイミング',
      state: '状態',
      execution: '実行',
      starts: '開始',
      ends: '終了',
      variables: '変数',
      processes: 'プロセス',
      database: 'データベース',
      array: '配列',
      structure: '構造',
      row: 'ロウ | ロウ',
      cell: 'セル | セル',
      triggerFunction: 'トリガー関数 | トリガー関数',
      routine: 'ルーチン',
      unableEditFieldWithoutPrimary: '主キーのないフィールドを結果セットで編集できない',
      editCell: 'セルの編集',
      deleteRows: '行の削除 | {count} 行の削除',
      confirmToDeleteRows: '1つの行を削除することを確認しますか？ | {count} 行を削除することを確認しますか？',
      addNewRow: '新しい行の追加',
      numberOfInserts: 'インサート数',
      affectedRows: '影響を受ける行',
      createNewDatabase: '新規データベースの作成',
      databaseName: 'データベース名',
      serverDefault: 'サーバーのデフォルト',
      deleteDatabase: 'データベースの削除',
      editDatabase: 'データベースの編集',
      clearChanges: '変更の消去',
      addNewField: '新しいフィールドの追加',
      manageIndexes: 'インデックスの管理',
      manageForeignKeys: '外部キーの管理',
      allowNull: 'NULL を許可する',
      zeroFill: 'ゼロフィル',
      customValue: 'カスタム値',
      onUpdate: '更新時',
      deleteField: 'フィールドの削除',
      createNewIndex: '新しいインデックスの作成',
      addToIndex: 'インデックスへの追加',
      createNewTable: '新しいテーブルの作成',
      emptyTable: '空のテーブル',
      deleteTable: 'テーブルの削除',
      emptyConfirm: '空にすることを確認しますか？',
      thereAreNoIndexes: 'インデックスがありません',
      thereAreNoForeign: '外部キーがありません。',
      createNewForeign: '新しい外部キーの作成',
      referenceTable: '参照テーブル',
      referenceField: '参照フィールド',
      foreignFields: '外部フィールド',
      invalidDefault: '無効なデフォルト',
      onDelete: '削除時',
      selectStatement: '選択文',
      triggerStatement: 'トリガー文',
      sqlSecurity: 'SQL セキュリティ',
      updateOption: '更新オプション',
      deleteView: 'ビューの削除',
      createNewView: '新規ビューの作成',
      deleteTrigger: 'トリガーの削除',
      createNewTrigger: '新しいトリガの作成',
      currentUser: '現在のユーザー',
      routineBody: 'ルーチン本体',
      dataAccess: 'データアクセス',
      thereAreNoParameters: 'パラメータはありません',
      createNewParameter: '新しいパラメータの作成',
      createNewRoutine: 'ストアド・ルーチンの新規作成',
      deleteRoutine: 'ストアド・ルーチンの削除',
      functionBody: '関数本体',
      createNewFunction: '新しい関数の作成',
      deleteFunction: '関数の削除',
      schedulerBody: 'スケジューラ本体',
      createNewScheduler: 'スケジューラの新規作成',
      deleteScheduler: 'スケジューラの削除',
      preserveOnCompletion: '完了時に保存する',
      tableFiller: 'テーブルフィラー',
      fakeDataLanguage: 'フェイクデータの言語',
      queryDuration: '問い合わせ期間',
      setNull: 'NULL の設定',
      processesList: 'プロセス一覧',
      processInfo: 'プロセス情報',
      manageUsers: 'ユーザーの管理',
      createNewSchema: '新しいスキーマの作成',
      schemaName: 'スキーマ名',
      editSchema: 'スキーマの編集',
      deleteSchema: 'スキーマの削除',
      duplicateTable: 'テーブルを複製する',
      noSchema: 'スキーマなし',
      runQuery: 'クエリの実行',
      thereAreNoTableFields: 'テーブルのフィールドがありません',
      newTable: '新しいテーブル',
      newView: '新しいビュー',
      newTrigger: '新しいトリガー',
      newRoutine: '新しいルーチン',
      newFunction: '新しい関数',
      newScheduler: '新規スケジューラ',
      newTriggerFunction: '新しいトリガー機能',
      thereIsNoQueriesYet: 'まだ問い合わせはありません',
      searchForQueries: 'クエリの検索',
      killProcess: 'プロセスの停止'
   },
   application: {
      settings: '設定',
      general: '一般',
      themes: 'テーマ',
      update: '更新情報',
      language: '言語',
      light: 'ライト',
      dark: 'ダーク',
      autoCompletion: 'オートコンプリート',
      application: 'アプリケーション',
      editor: 'エディター',
      scratchpad: 'スクラッチパッド',
      changelog: '変更履歴',
      madeWithJS: '💛 と JavaScript で作られています。',
      checkForUpdates: '更新情報の確認',
      noUpdatesAvailable: 'アップデートがありません',
      checkingForUpdate: 'アップデートを確認中',
      checkFailure: 'チェックに失敗しました、後で試してください',
      updateAvailable: 'アップデートが利用可能です',
      downloadingUpdate: 'アップデートのダウンロード',
      updateDownloaded: 'アップデートのダウンロード',
      restartToInstall: 'Antares を再起動してインストールしてください',
      notificationsTimeout: '通知のタイムアウト',
      openNewTab: '新しいタブを開く',
      unsavedChanges: '保存されていない変更',
      discardUnsavedChanges: '保存されていない変更があります。このタブを閉じると、これらの変更は破棄されます。',
      applicationTheme: 'アプリケーションテーマ',
      editorTheme: 'エディターテーマ',
      wrapLongLines: '長い行の折り返し',
      includeBetaUpdates: 'ベータ版アップデートを含む',
      markdownSupported: 'マークダウン対応',
      dataTabPageSize: 'DATA タブのページサイズ',
      noOpenTabs: '開いているタブがありません。左のバーでナビゲートするか',
      restorePreviousSession: '前のセッションに戻す',
      searchForElements: '要素の検索'
   },
   faker: {
      address: '住所',
      commerce: 'コマース',
      company: '会社名',
      database: 'データベース',
      date: '日付',
      finance: 'ファイナンス',
      // git: 'ギット',
      hacker: 'ハッカー',
      internet: 'インターネット',
      // lorem: 'ローレム',
      name: '名前',
      music: '音楽',
      phone: '電話',
      random: 'ランダム',
      system: 'システム',
      time: '時間',
      vehicle: '車',
      zipCode: '郵便番号',
      zipCodeByState: '都道府県別郵便番号',
      city: '都市名',
      cityPrefix: '市のプレフィックス',
      citySuffix: '市の接尾辞',
      streetName: '通りの名前',
      streetAddress: 'ストリートアドレス',
      streetSuffix: '通りの接尾辞',
      streetPrefix: 'ストリートプレフィックス',
      secondaryAddress: '副住所',
      county: '郡',
      country: '国名',
      countryCode: '国コード',
      state: '州',
      stateAbbr: '州の略語',
      latitude: '緯度',
      longitude: '経度',
      direction: '方向',
      cardinalDirection: '枢機卿の方向',
      ordinalDirection: '序列方向',
      nearbyGPSCoordinate: '近くのGPS座標',
      timeZone: 'タイムゾーン',
      color: '色',
      department: '部門',
      productName: '商品名',
      price: '価格',
      productAdjective: '製品の形容詞',
      productMaterial: '製品の素材',
      product: '製品',
      productDescription: '製品の説明',
      suffixes: 'サフィックス',
      companyName: '会社名',
      companySuffix: '会社のサフィックス',
      catchPhrase: 'キャッチフレーズ',
      // bs: 'BS',
      catchPhraseAdjective: 'キャッチフレーズ形容詞',
      catchPhraseDescriptor: 'キャッチフレーズの説明文',
      catchPhraseNoun: 'キャッチフレーズの名詞',
      bsAdjective: 'BS 形容詞',
      bsBuzz: 'BS の話題',
      bsNoun: 'BS の名詞',
      column: 'コラム',
      type: 'タイプ',
      collation: '照合',
      engine: 'エンジン',
      past: '過去',
      future: '未来',
      between: '間',
      recent: '最近',
      soon: 'すぐ',
      month: '月',
      weekday: '曜日',
      account: 'アカウント',
      accountName: '口座名',
      routingNumber: 'ルーティング番号',
      mask: 'マスク',
      amount: '金額',
      transactionType: '取引の種類',
      currencyCode: '通貨コード',
      currencyName: '通貨名',
      currencySymbol: '通貨記号',
      bitcoinAddress: 'Bitcoin アドレス',
      litecoinAddress: 'ライトコインのアドレス',
      creditCardNumber: 'クレジットカード番号',
      creditCardCVV: 'クレジットカードの CVV',
      ethereumAddress: 'イーサリアムのアドレス',
      iban: 'アイバン',
      bic: 'ビック',
      transactionDescription: '取引内容',
      branch: 'ブランチ',
      commitEntry: 'コミットエントリ',
      commitMessage: 'コミットメッセージ',
      commitSha: 'コミット SHA',
      shortSha: 'ショート SHA',
      abbreviation: '省略形',
      adjective: '形容詞',
      noun: '名詞',
      verb: '動詞',
      ingverb: '動詞',
      phrase: 'フレーズ',
      avatar: 'アバター',
      email: 'メール',
      exampleEmail: 'メールの例',
      userName: 'ユーザー名',
      protocol: 'プロトコル',
      url: 'URL',
      domainName: 'ドメイン名',
      domainSuffix: 'ドメインのサフィックス',
      domainWord: 'ドメイン名',
      ip: 'Ip',
      ipv6: 'Ipv6',
      userAgent: 'ユーザーエージェント',
      // mac: 'Mac',
      password: 'パスワード',
      word: 'ワード',
      words: '単語',
      sentence: '文章',
      slug: 'スラッグ',
      sentences: 'センテンス',
      paragraph: 'パラグラフ',
      paragraphs: 'パラグラフ',
      text: 'テキスト',
      lines: '行',
      genre: 'ジャンル',
      firstName: 'ファーストネーム',
      lastName: '苗字',
      middleName: 'ミドルネーム',
      findName: 'フルネーム',
      jobTitle: '役職名',
      gender: '性別',
      prefix: 'プレフィックス',
      suffix: 'サフィックス',
      title: '役職名',
      jobDescriptor: '職務記述書',
      jobArea: '職務領域',
      jobType: '仕事の種類',
      phoneNumber: '電話番号',
      phoneNumberFormat: '電話番号のフォーマット',
      phoneFormats: '電話番号のフォーマット',
      // number: '番号',
      // float: 'フロート',
      arrayElement: '配列要素',
      arrayElements: '配列要素',
      objectElement: 'オブジェクトの要素',
      // uuid: 'Uuid',
      // boolean: 'ブール',
      image: '画像',
      locale: 'ロケール',
      alpha: '英字',
      alphaNumeric: '英数字',
      hexaDecimal: '16進法',
      fileName: 'ファイル名',
      commonFileName: '一般的なファイル名',
      mimeType: 'Mimeタイプ',
      commonFileType: '共通のファイルタイプ',
      commonFileExt: '共通のファイル拡張子',
      fileType: 'ファイルタイプ',
      fileExt: 'ファイル拡張子',
      directoryPath: 'ディレクトリパス',
      filePath: 'ファイルパス',
      // semver: 'セムバー',
      manufacturer: 'メーカー名',
      model: 'モデル',
      fuel: '燃料'
      // vin: 'Vin'
   }
};
